==> blancoMessage-0.4.0-src.zip: src/blanco/resourcebundle/task/BlancoResourceBundleTask.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * Apache Ant^XN [BlancoResourceBundle]̃NX
 */
package blanco.resourcebundle.task;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;

import blanco.resourcebundle.task.valueobject.BlancoResourceBundleProcessInput;

/**
 * Apache Ant^XN [BlancoResourceBundle]̃NXB
 *
 * BlancoResourceBundleAntTaskłB<br>
 * ̃NXł́AApache Ant^XNňʓIɕKvȃ`FbNȂǂ̃R[fBO肵܂B
 * ۂ̏ pbP[W[blanco.resourcebundle.task]BlancoResourceBundleBatchProcessNX쐬ċLqĂB<br>
 * <br>
 * Ant^XNւ̑gݍݗ<br>
 * <pre>
 * &lt;taskdef name=&quot;blancoresourcebundle&quot; classname=&quot;blanco.resourcebundle.task.BlancoResourceBundleTask">
 *     &lt;classpath&gt;
 *         &lt;fileset dir=&quot;lib&quot; includes=&quot;*.jar&quot; /&gt;
 *         &lt;fileset dir=&quot;lib.ant&quot; includes=&quot;*.jar&quot; /&gt;
 *     &lt;/classpath&gt;
 * &lt;/taskdef&gt;
 * </pre>
 */
public class BlancoResourceBundleTask extends Task {
    /**
     * BlancoResourceBundleAntTaskłB
     */
    protected BlancoResourceBundleProcessInput fInput = new BlancoResourceBundleProcessInput();

    /**
     * BlancoResourceBundleAntTaskłB
     */
    protected boolean fIsFieldMetadirProcessed = false;

    /**
     * BlancoResourceBundleAntTaskłB
     */
    protected boolean fIsFieldTargetdirProcessed = false;

    /**
     * BlancoResourceBundleAntTaskłB
     */
    protected boolean fIsFieldTmpdirProcessed = false;

    /**
     * BlancoResourceBundleAntTaskłB
     */
    protected boolean fIsFieldCommenttimestampProcessed = false;

    /**
     * BlancoResourceBundleAntTaskłB
     */
    protected boolean fIsFieldFailonmessageformaterrorProcessed = false;

    /**
     * BlancoResourceBundleAntTaskłB
     */
    protected boolean fIsFieldLogProcessed = false;

    /**
     * verbose[hœ삳邩ǂB
     *
     * @param arg verbose[hœ삳邩ǂB
     */
    public void setVerbose(final boolean arg) {
        fInput.setVerbose(arg);
    }

    /**
     * verbose[hœ삳邩ǂB
     *
     * @return verbose[hœ삳邩ǂB
     */
    public boolean getVerbose() {
        return fInput.getVerbose();
    }

    /**
     * Ant^XN[metadir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 1<br>
     * ^fBNg<br>
     *
     * @param arg Zbgl
     */
    public void setMetadir(final String arg) {
        fInput.setMetadir(arg);
        fIsFieldMetadirProcessed = true;
    }

    /**
     * Ant^XN[metadir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 1<br>
     * ^fBNg<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getMetadir() {
        return fInput.getMetadir();
    }

    /**
     * Ant^XN[targetdir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 2<br>
     * o͐tH_w肵܂Bw̏ꍇɂ̓Jgblancop܂B<br>
     *
     * @param arg Zbgl
     */
    public void setTargetdir(final String arg) {
        fInput.setTargetdir(arg);
        fIsFieldTargetdirProcessed = true;
    }

    /**
     * Ant^XN[targetdir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 2<br>
     * o͐tH_w肵܂Bw̏ꍇɂ̓Jgblancop܂B<br>
     * ftHgl[blanco]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getTargetdir() {
        return fInput.getTargetdir();
    }

    /**
     * Ant^XN[tmpdir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 3<br>
     * e|tH_w肵܂Bw̏ꍇɂ́AJgtmpp܂B<br>
     *
     * @param arg Zbgl
     */
    public void setTmpdir(final String arg) {
        fInput.setTmpdir(arg);
        fIsFieldTmpdirProcessed = true;
    }

    /**
     * Ant^XN[tmpdir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 3<br>
     * e|tH_w肵܂Bw̏ꍇɂ́AJgtmpp܂B<br>
     * ftHgl[tmp]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getTmpdir() {
        return fInput.getTmpdir();
    }

    /**
     * Ant^XN[commenttimestamp]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 4<br>
     * vpeBt@C̐ɂāAvpeBt@C̃Rgɏo͂邩ǂtOB<br>
     *
     * @param arg Zbgl
     */
    public void setCommenttimestamp(final boolean arg) {
        fInput.setCommenttimestamp(arg);
        fIsFieldCommenttimestampProcessed = true;
    }

    /**
     * Ant^XN[commenttimestamp]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 4<br>
     * vpeBt@C̐ɂāAvpeBt@C̃Rgɏo͂邩ǂtOB<br>
     * ftHgl[true]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public boolean getCommenttimestamp() {
        return fInput.getCommenttimestamp();
    }

    /**
     * Ant^XN[failonmessageformaterror]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 5<br>
     * \[XohMessageFormatɂp[XsۂɁAO珈𒆒f邩ǂ̃tOBtrueȂ珈fėO𔭐܂BfalseȂ珈sAû͖Ƃ݂Ȃ܂BJavã\[XR[hۂȂǂɁA falseɐݒ肵ĔgʂƂł悤ɐ؂ւꍇ܂B<br>
     *
     * @param arg Zbgl
     */
    public void setFailonmessageformaterror(final boolean arg) {
        fInput.setFailonmessageformaterror(arg);
        fIsFieldFailonmessageformaterrorProcessed = true;
    }

    /**
     * Ant^XN[failonmessageformaterror]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 5<br>
     * \[XohMessageFormatɂp[XsۂɁAO珈𒆒f邩ǂ̃tOBtrueȂ珈fėO𔭐܂BfalseȂ珈sAû͖Ƃ݂Ȃ܂BJavã\[XR[hۂȂǂɁA falseɐݒ肵ĔgʂƂł悤ɐ؂ւꍇ܂B<br>
     * ftHgl[true]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public boolean getFailonmessageformaterror() {
        return fInput.getFailonmessageformaterror();
    }

    /**
     * Ant^XN[log]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 6<br>
     * Oo͂\[XR[hɊ܂߂邩ǂ̃tOBo͂ꍇɂ java.util.logging.Logger݂̂ɑΉB<br>
     *
     * @param arg Zbgl
     */
    public void setLog(final boolean arg) {
        fInput.setLog(arg);
        fIsFieldLogProcessed = true;
    }

    /**
     * Ant^XN[log]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 6<br>
     * Oo͂\[XR[hɊ܂߂邩ǂ̃tOBo͂ꍇɂ java.util.logging.Logger݂̂ɑΉB<br>
     * ftHgl[false]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public boolean getLog() {
        return fInput.getLog();
    }

    /**
     * Ant^XÑCBApache Ant ̃\bhĂяo܂B
     *
     * @throws BuildException ^XNƂĂ̗OꍇB
     */
    public final void execute() throws BuildException {
        System.out.println("BlancoResourceBundleTask begin.");

        // ڔԍ[1]AAgr[g[metadir]͕K{͂łB̓`FbNs܂B
        if (fIsFieldMetadirProcessed == false) {
            throw new BuildException("K{Agr[g[metadir]ݒ肳Ă܂B𒆒f܂B");
        }

        if (getVerbose()) {
            System.out.println("- verbose:[true]");
            System.out.println("- metadir:[" + getMetadir() + "]");
            System.out.println("- targetdir:[" + getTargetdir() + "]");
            System.out.println("- tmpdir:[" + getTmpdir() + "]");
            System.out.println("- commenttimestamp:[" + getCommenttimestamp() + "]");
            System.out.println("- failonmessageformaterror:[" + getFailonmessageformaterror() + "]");
            System.out.println("- log:[" + getLog() + "]");
        }

        try {
            // ۂAnt^XN̎又s܂B
            // ̉ӏŃRpCG[ꍇABlancoResourceBundleProcessC^tF[X blanco.resourcebundle.taskpbP[W BlancoResourceBundleProcessImplNX쐬邱Ƃɂłꍇ܂B
            final BlancoResourceBundleProcess proc = new BlancoResourceBundleProcessImpl();
            if (proc.execute(fInput) != BlancoResourceBundleBatchProcess.END_SUCCESS) {
                throw new BuildException("^XNُ͈I܂B");
            }
        } catch (IllegalArgumentException e) {
            if (getVerbose()) {
                e.printStackTrace();
            }
            throw new BuildException(e.getMessage());
        } catch (Exception e) {
            e.printStackTrace();
            throw new BuildException("^XNɗO܂B𒆒f܂B" + e.toString());
        } catch (Error e) {
            e.printStackTrace();
            throw new BuildException("^XNɃG[܂B𒆒f܂B" + e.toString());
        }
    }
}

==> blancoMessage-0.5.3-src.zip: src/blanco/resourcebundle/task/BlancoResourceBundleTask.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * Apache Ant^XN [BlancoResourceBundle]̃NX
 */
package blanco.resourcebundle.task;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.Task;

import blanco.resourcebundle.task.valueobject.BlancoResourceBundleProcessInput;

/**
 * Apache Ant^XN [BlancoResourceBundle]̃NXB
 *
 * BlancoResourceBundleAntTaskłB<br>
 * ̃NXł́AApache Ant^XNňʓIɕKvȃ`FbNȂǂ̃R[fBO肵܂B
 * ۂ̏ pbP[W[blanco.resourcebundle.task]BlancoResourceBundleBatchProcessNX쐬ċLqĂB<br>
 * <br>
 * Ant^XNւ̑gݍݗ<br>
 * <pre>
 * &lt;taskdef name=&quot;blancoresourcebundle&quot; classname=&quot;blanco.resourcebundle.task.BlancoResourceBundleTask">
 *     &lt;classpath&gt;
 *         &lt;fileset dir=&quot;lib&quot; includes=&quot;*.jar&quot; /&gt;
 *         &lt;fileset dir=&quot;lib.ant&quot; includes=&quot;*.jar&quot; /&gt;
 *     &lt;/classpath&gt;
 * &lt;/taskdef&gt;
 * </pre>
 */
public class BlancoResourceBundleTask extends Task {
    /**
     * BlancoResourceBundleAntTaskłB
     */
    protected BlancoResourceBundleProcessInput fInput = new BlancoResourceBundleProcessInput();

    /**
     * BlancoResourceBundleAntTaskłB
     */
    protected boolean fIsFieldMetadirProcessed = false;

    /**
     * BlancoResourceBundleAntTaskłB
     */
    protected boolean fIsFieldTargetdirProcessed = false;

    /**
     * BlancoResourceBundleAntTaskłB
     */
    protected boolean fIsFieldTmpdirProcessed = false;

    /**
     * BlancoResourceBundleAntTaskłB
     */
    protected boolean fIsFieldCommenttimestampProcessed = false;

    /**
     * BlancoResourceBundleAntTaskłB
     */
    protected boolean fIsFieldFailonmessageformaterrorProcessed = false;

    /**
     * BlancoResourceBundleAntTaskłB
     */
    protected boolean fIsFieldLogProcessed = false;

    /**
     * BlancoResourceBundleAntTaskłB
     */
    protected boolean fIsFieldPropertieswithdirectoryProcessed = false;

    /**
     * verbose[hœ삳邩ǂB
     *
     * @param arg verbose[hœ삳邩ǂB
     */
    public void setVerbose(final boolean arg) {
        fInput.setVerbose(arg);
    }

    /**
     * verbose[hœ삳邩ǂB
     *
     * @return verbose[hœ삳邩ǂB
     */
    public boolean getVerbose() {
        return fInput.getVerbose();
    }

    /**
     * Ant^XN[metadir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 1<br>
     * ^fBNg<br>
     *
     * @param arg Zbgl
     */
    public void setMetadir(final String arg) {
        fInput.setMetadir(arg);
        fIsFieldMetadirProcessed = true;
    }

    /**
     * Ant^XN[metadir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 1<br>
     * ^fBNg<br>
     * K{Agr[głBApache Ant^XNŕKlw肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getMetadir() {
        return fInput.getMetadir();
    }

    /**
     * Ant^XN[targetdir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 2<br>
     * o͐tH_w肵܂Bw̏ꍇɂ̓Jgblancop܂B<br>
     *
     * @param arg Zbgl
     */
    public void setTargetdir(final String arg) {
        fInput.setTargetdir(arg);
        fIsFieldTargetdirProcessed = true;
    }

    /**
     * Ant^XN[targetdir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 2<br>
     * o͐tH_w肵܂Bw̏ꍇɂ̓Jgblancop܂B<br>
     * ftHgl[blanco]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getTargetdir() {
        return fInput.getTargetdir();
    }

    /**
     * Ant^XN[tmpdir]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 3<br>
     * e|tH_w肵܂Bw̏ꍇɂ́AJgtmpp܂B<br>
     *
     * @param arg Zbgl
     */
    public void setTmpdir(final String arg) {
        fInput.setTmpdir(arg);
        fIsFieldTmpdirProcessed = true;
    }

    /**
     * Ant^XN[tmpdir]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 3<br>
     * e|tH_w肵܂Bw̏ꍇɂ́AJgtmpp܂B<br>
     * ftHgl[tmp]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public String getTmpdir() {
        return fInput.getTmpdir();
    }

    /**
     * Ant^XN[commenttimestamp]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 4<br>
     * vpeBt@C̐ɂāAvpeBt@C̃Rgɏo͂邩ǂtOB<br>
     *
     * @param arg Zbgl
     */
    public void setCommenttimestamp(final boolean arg) {
        fInput.setCommenttimestamp(arg);
        fIsFieldCommenttimestampProcessed = true;
    }

    /**
     * Ant^XN[commenttimestamp]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 4<br>
     * vpeBt@C̐ɂāAvpeBt@C̃Rgɏo͂邩ǂtOB<br>
     * ftHgl[true]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public boolean getCommenttimestamp() {
        return fInput.getCommenttimestamp();
    }

    /**
     * Ant^XN[failonmessageformaterror]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 5<br>
     * \[XohMessageFormatɂp[XsۂɁAO珈𒆒f邩ǂ̃tOBtrueȂ珈fėO𔭐܂BfalseȂ珈sAû͖Ƃ݂Ȃ܂BJavã\[XR[hۂȂǂɁA falseɐݒ肵ĔgʂƂł悤ɐ؂ւꍇ܂B<br>
     *
     * @param arg Zbgl
     */
    public void setFailonmessageformaterror(final boolean arg) {
        fInput.setFailonmessageformaterror(arg);
        fIsFieldFailonmessageformaterrorProcessed = true;
    }

    /**
     * Ant^XN[failonmessageformaterror]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 5<br>
     * \[XohMessageFormatɂp[XsۂɁAO珈𒆒f邩ǂ̃tOBtrueȂ珈fėO𔭐܂BfalseȂ珈sAû͖Ƃ݂Ȃ܂BJavã\[XR[hۂȂǂɁA falseɐݒ肵ĔgʂƂł悤ɐ؂ւꍇ܂B<br>
     * ftHgl[true]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public boolean getFailonmessageformaterror() {
        return fInput.getFailonmessageformaterror();
    }

    /**
     * Ant^XN[log]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 6<br>
     * Oo͂\[XR[hɊ܂߂邩ǂ̃tOBo͂ꍇɂ java.util.logging.Logger݂̂ɑΉB<br>
     *
     * @param arg Zbgl
     */
    public void setLog(final boolean arg) {
        fInput.setLog(arg);
        fIsFieldLogProcessed = true;
    }

    /**
     * Ant^XN[log]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 6<br>
     * Oo͂\[XR[hɊ܂߂邩ǂ̃tOBo͂ꍇɂ java.util.logging.Logger݂̂ɑΉB<br>
     * ftHgl[false]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public boolean getLog() {
        return fInput.getLog();
    }

    /**
     * Ant^XN[propertieswithdirectory]Agr[g̃Zb^[\bhB
     *
     * ڔԍ: 7<br>
     * vpeBt@CfBNgtŏo͂邩ǂ̃tOB<br>
     *
     * @param arg Zbgl
     */
    public void setPropertieswithdirectory(final boolean arg) {
        fInput.setPropertieswithdirectory(arg);
        fIsFieldPropertieswithdirectoryProcessed = true;
    }

    /**
     * Ant^XN[propertieswithdirectory]Agr[g̃Qb^[\bhB
     *
     * ڔԍ: 7<br>
     * vpeBt@CfBNgtŏo͂邩ǂ̃tOB<br>
     * ftHgl[true]ݒ肳Ă܂BApache Ant^XNŃAgr[g̎w肪ꍇɂ́AftHglݒ肳܂B<br>
     *
     * @return ̃tB[h̒l
     */
    public boolean getPropertieswithdirectory() {
        return fInput.getPropertieswithdirectory();
    }

    /**
     * Ant^XÑCBApache Ant ̃\bhĂяo܂B
     *
     * @throws BuildException ^XNƂĂ̗OꍇB
     */
    public final void execute() throws BuildException {
        System.out.println("BlancoResourceBundleTask begin.");

        // ڔԍ[1]AAgr[g[metadir]͕K{͂łB̓`FbNs܂B
        if (fIsFieldMetadirProcessed == false) {
            throw new BuildException("K{Agr[g[metadir]ݒ肳Ă܂B𒆒f܂B");
        }

        if (getVerbose()) {
            System.out.println("- verbose:[true]");
            System.out.println("- metadir:[" + getMetadir() + "]");
            System.out.println("- targetdir:[" + getTargetdir() + "]");
            System.out.println("- tmpdir:[" + getTmpdir() + "]");
            System.out.println("- commenttimestamp:[" + getCommenttimestamp() + "]");
            System.out.println("- failonmessageformaterror:[" + getFailonmessageformaterror() + "]");
            System.out.println("- log:[" + getLog() + "]");
            System.out.println("- propertieswithdirectory:[" + getPropertieswithdirectory() + "]");
        }

        try {
            // ۂAnt^XN̎又s܂B
            // ̉ӏŃRpCG[ꍇABlancoResourceBundleProcessC^tF[X blanco.resourcebundle.taskpbP[W BlancoResourceBundleProcessImplNX쐬邱Ƃɂłꍇ܂B
            final BlancoResourceBundleProcess proc = new BlancoResourceBundleProcessImpl();
            if (proc.execute(fInput) != BlancoResourceBundleBatchProcess.END_SUCCESS) {
                throw new BuildException("^XNُ͈I܂B");
            }
        } catch (IllegalArgumentException e) {
            if (getVerbose()) {
                e.printStackTrace();
            }
            throw new BuildException(e.getMessage());
        } catch (Exception e) {
            e.printStackTrace();
            throw new BuildException("^XNɗO܂B𒆒f܂B" + e.toString());
        } catch (Error e) {
            e.printStackTrace();
            throw new BuildException("^XNɃG[܂B𒆒f܂B" + e.toString());
        }
    }
}
